pkgsrc-Changes archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

CVS commit: pkgsrc/net/tinydyndns-run



Module Name:    pkgsrc
Committed By:   schmonz
Date:           Fri Apr 25 20:41:12 UTC 2025

Modified Files:
        pkgsrc/net/tinydyndns-run: Makefile
        pkgsrc/net/tinydyndns-run/files: tinydyndns-pwhash.py

Log Message:
tinydyndns-run: python313 dropped crypt, use bcrypt. Bump version.

cvm-pwfile still uses crypt() to verify logins, so hopefully
Blowfish-hashed passwords are sufficiently broadly available to not
cause trouble on any pkgsrc platforms.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 pkgsrc/net/tinydyndns-run/Makefile
cvs rdiff -u -r1.2 -r1.3 pkgsrc/net/tinydyndns-run/files/tinydyndns-pwhash.py

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: pkgsrc/net/tinydyndns-run/Makefile
diff -u pkgsrc/net/tinydyndns-run/Makefile:1.7 pkgsrc/net/tinydyndns-run/Makefile:1.8
--- pkgsrc/net/tinydyndns-run/Makefile:1.7      Mon Aug 14 05:25:04 2023
+++ pkgsrc/net/tinydyndns-run/Makefile  Fri Apr 25 20:41:11 2025
@@ -1,8 +1,6 @@
-# $NetBSD: Makefile,v 1.7 2023/08/14 05:25:04 wiz Exp $
-#
+# $NetBSD: Makefile,v 1.8 2025/04/25 20:41:11 schmonz Exp $
 
-DISTNAME=              tinydyndns-run-20201030
-PKGREVISION=           3
+DISTNAME=              tinydyndns-run-20250425
 CATEGORIES=            net
 MASTER_SITES=          # empty
 DISTFILES=             # empty
@@ -11,6 +9,7 @@ MAINTAINER=            schmonz%NetBSD.org@localhost
 COMMENT=               Configures tinydyndns to serve and update records
 LICENSE=               2-clause-bsd
 
+DEPENDS+=              ${PYPKGPREFIX}-passlib-[0-9]*:../../security/py-passlib
 DEPENDS+=              nopop3d-[0-9]*:../../mail/nopop3d
 DEPENDS+=              qmail-[0-9]*:../../mail/qmail
 DEPENDS+=              tinydyndns-[0-9]*:../../net/tinydyndns

Index: pkgsrc/net/tinydyndns-run/files/tinydyndns-pwhash.py
diff -u pkgsrc/net/tinydyndns-run/files/tinydyndns-pwhash.py:1.2 pkgsrc/net/tinydyndns-run/files/tinydyndns-pwhash.py:1.3
--- pkgsrc/net/tinydyndns-run/files/tinydyndns-pwhash.py:1.2    Mon Oct 19 07:15:55 2020
+++ pkgsrc/net/tinydyndns-run/files/tinydyndns-pwhash.py        Fri Apr 25 20:41:11 2025
@@ -1,9 +1,10 @@
 #!/usr/bin/env python
 #
-# $NetBSD: tinydyndns-pwhash.py,v 1.2 2020/10/19 07:15:55 schmonz Exp $
+# $NetBSD: tinydyndns-pwhash.py,v 1.3 2025/04/25 20:41:11 schmonz Exp $
 #
 # @PKGNAME@ program to crypt() a password.
 
-import crypt, sys
+from passlib.context import CryptContext
+import sys
 
-print(crypt.crypt(sys.stdin.read().rstrip()))
+print(CryptContext(schemes=["bcrypt"]).hash(sys.stdin.read().rstrip()))
@@ -1,9 +1,10 @@
 #
-# @PKGNAME@ program to crypt() a password.
+# @PKGNAME@ program to bcrypt a password.
 



Home | Main Index | Thread Index | Old Index